@@ -1,4 +1,6 @@
-from fakeredis.stack import JSONCommandsMixin
+from typing import Optional, Set
+
+from fakeredis.stack import JSONCommandsMixin, BFCommandsMixin, CFCommandsMixin, CMSCommandsMixin, TopkCommandsMixin
 from ._basefakesocket import BaseFakeSocket
 from .commands_mixins.bitmap_mixin import BitmapCommandsMixin
 from .commands_mixins.connection_mixin import ConnectionCommandsMixin
@@ -7,7 +9,15 @@ from .commands_mixins.geo_mixin import GeoCommandsMixin
 from .commands_mixins.hash_mixin import HashCommandsMixin
 from .commands_mixins.list_mixin import ListCommandsMixin
 from .commands_mixins.pubsub_mixin import PubSubCommandsMixin
-from .commands_mixins.scripting_mixin import ScriptingCommandsMixin
+
+try:
+    from .commands_mixins.scripting_mixin import ScriptingCommandsMixin
+except ImportError:
+    class ScriptingCommandsMixin:  # type: ignore  # noqa: E303
+        def __init__(self, *args, **kwargs) -> None:
+            kwargs.pop("lua_modules", None)
+            super(ScriptingCommandsMixin, self).__init__(*args, **kwargs)
+
 from .commands_mixins.server_mixin import ServerCommandsMixin
 from .commands_mixins.set_mixin import SetCommandsMixin
 from .commands_mixins.sortedset_mixin import SortedSetCommandsMixin
@@ -33,6 +43,12 @@ class FakeSocket(
     StreamsCommandsMixin,
     JSONCommandsMixin,
     GeoCommandsMixin,
+    BFCommandsMixin,
+    CFCommandsMixin,
+    CMSCommandsMixin,
+    TopkCommandsMixin,
 ):
-    def __init__(self, server, db):
-        super(FakeSocket, self).__init__(server, db)
+    def __init__(
+            self, server: "FakeServer", db: int, lua_modules: Optional[Set[str]] = None,  # type: ignore # noqa: F821
+    ) -> None:
+        super(FakeSocket, self).__init__(server, db, lua_modules=lua_modules)
